@@ -1,4 +1,4 @@
-/*	$Id: ClassModem.h,v 1.26 2007/06/05 17:30:16 aidan Exp $ */
+/*	$Id: ClassModem.h,v 1.15 2008/07/16 16:17:39 faxguy Exp $ */
 /*
  * Copyright (c) 1994-1996 Sam Leffler
  * Copyright (c) 1994-1996 Silicon Graphics, Inc.
@@ -31,7 +31,6 @@
 #include <stdarg.h>
 #include "Str.h"
 #include "CallID.h"
-#include "Status.h"
 
 class ModemServer;
 class ModemConfig;
@@ -180,7 +179,8 @@ public:
 	AT_DLEEOT	= 14,	// dle+eot characters (end of transmission)
 	AT_XON		= 15,	// xon character
 	AT_DTMF		= 16,	// DTMF detection
-	AT_OTHER	= 17	// unknown response (not one of above)
+	AT_VCON		= 17,	// voice connection
+	AT_OTHER	= 18	// unknown response (not one of above)
     };
 private:
     ModemServer& server;	// server for getting to device
@@ -204,8 +204,8 @@ protected:
     fxStr	revQueryCmd;	// product revision identification command
 
     static const char* serviceNames[9];	 // class 2 services
-    static Status callStatus[10];	 // printable call status
-    static const char* ATresponses[17];
+    static const char* callStatus[10];	 // printable call status
+    static const char* ATresponses[19];
 
     ClassModem(ModemServer&, const ModemConfig&);
 
@@ -219,8 +219,8 @@ protected:
     bool doQuery(const fxStr& queryCmd, fxStr& result, long ms = 30*1000);
 // dial/answer interactions with derived classes
     virtual const AnswerMsg* findAnswer(const char* s);
-    virtual CallType answerResponse(Status& eresult);
-    virtual CallStatus dialResponse(Status& eresult) = 0;
+    virtual CallType answerResponse(fxStr, fxStr& emsg);
+    virtual CallStatus dialResponse(fxStr& emsg) = 0;
     virtual bool isNoise(const char*);
 // miscellaneous
     void	modemSupports(const char* fmt, ...);
@@ -247,6 +247,10 @@ public:
     const fxStr& getRevision() const;
     fxStr	getCapabilities() const;
     u_int	getModemServices() const;
+    bool	doCallIDDisplay(int i) const;
+    bool	doCallIDRecord(int i) const;
+    const fxStr& getCallIDLabel(int i) const;
+    const fxStr& getCallIDType(int i) const;
 // data transfer timeout controls
     void	setDataTimeout(long secs, u_int br);
     long	getDataTimeout() const;
@@ -265,18 +269,19 @@ public:
     void	setTimeout(bool);
     void	flushModemInput();
     bool	putModem(void* data, int n, long ms = 0);
-    bool	putModemData(void* data, int n);
+    bool	putModemData(void* data, int n, long ms = -1);
     bool	putModemDLEData(const u_char* data, u_int,
-		    const u_char* brev, long ms);
+		    const u_char* brev, long ms, bool doquery = false);
     bool	putModemLine(const char* cp, long ms = 0);
     int		getModemBit(long ms = 0);
-    int		getModemChar(long ms = 0);
+    int		getModemChar(long ms = 0, bool doquery = false);
     int		getModemDataChar();
     int		getLastByte();
     bool	didBlockEnd();
     void	resetBlock();
     void	startTimeout(long ms);
     void	stopTimeout(const char* whichdir);
+    bool	poke();
 // host-modem protocol parsing support
     virtual ATResponse atResponse(char* buf, long ms = 30*1000);
     bool	waitFor(ATResponse wanted, long ms = 30*1000);
@@ -301,19 +306,19 @@ public:
     /*
      * Send support:
      *
-     * if (dial(number, params, eresult) == OK) {
+     * if (dial(number, origin, emsg) == OK) {
      *	  ...do stuff...
      * }
      * hangup();
      */
     virtual bool dataService();
-    virtual CallStatus dial(const char* number, Status& eresult);
+    virtual CallStatus dial(const char* number, const char* origin, fxStr& emsg);
 
     /*
      * Receive support:
      *
      * if (waitForRings(nrings, ctype, cid)) {	// wait before answering phone
-     *    case (answerCall(type, eresult)) {
+     *    case (answerCall(type, emsg)) {
      *    CALLTYPE_FAX:
      *	        ...do fax kinds of things...
      *      break;
@@ -330,13 +335,8 @@ public:
      * at any time in this procedure.
      */
     virtual bool waitForRings(u_short rings, CallType&, CallID&);
-    virtual CallType answerCall(AnswerType, Status& eresult, const char* dialnumber = NULL);
+    virtual CallType answerCall(AnswerType, fxStr& emsg, const char* dialnumber = NULL);
     virtual void answerCallCmd(CallType);
-
-    /*
-     * Voice support
-     */
-    virtual void playFile (u_int id);
 };
 inline long ClassModem::getDataTimeout() const		{ return dataTimeout; }
 inline const fxStr& ClassModem::getModel() const	{ return modemModel; }
