@@ -1,4 +1,4 @@
-/*	$Id: DestInfo.h,v 1.7 2007/05/04 17:28:32 aidan Exp $ */
+/*	$Id: DestInfo.h,v 1.2 2007/01/05 21:57:24 faxguy Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -32,7 +32,7 @@
 #include "FaxMachineInfo.h"
 #include "Dictionary.h"
 
-class Batch;
+class Job;
 class fxStr;
 
 /*
@@ -47,35 +47,46 @@ class fxStr;
  * dictionary (e.g. explicit mechanisms for reading and updating
  * the external file). 
  */ 
-class DestInfo 
-  : public QLink
-{
+class DestInfo : public QLink {
 private:
     u_short		activeCount;	// count of active jobs to destination
+    u_short		blockedCount;	// count of blocked jobs
+    u_short		callCount;	// count of active calls to destination
     FaxMachineInfo	info;		// remote machine capabilities and such
-    Batch*		running;	// jobs to dest being processed
+    Job*		running;	// jobs to dest being processed
 public:
-    QLink		readyQ;		// list of ready jobs
-    QLink		sleepQ;		// list of sleeping jobs
-
     DestInfo();
     DestInfo(const DestInfo& other);
     ~DestInfo();
 
-    u_int getActiveCount() const;		// return count of active jobs
-    u_int getSleepCount() const;		// return count of active jobs
-    u_int getReadyCount() const;		// return count of ready jobs
-
+    u_int getActive() const;		// return count of active jobs
+    u_int getBlocked() const;		// return count of blocked jobs
+    u_int getCount() const;		// return count of active+blocked jobs
     bool isEmpty() const;		// true if any jobs referenced
+    u_int getCalls() const;		// return count of active calls
+    void call();			// initiate call to destination
+    void hangup();			// terminate call to destination
 
-    bool isActive(Batch&) const;	// true if job is considered active
-    void active(Batch&);			// set job active to destination
-    void done(Batch&);			// remove job from active set
+    bool isActive(Job&) const;	// true if job is considered active
+    bool supportsBatching();		// if remote supports batch protocol
+    void active(Job&);			// set job active to destination
+    void done(Job&);			// remove job from active set
+    void block(Job&);			// add job to blocked queue
+    Job* nextBlocked();			// remove and return first blocked job
+    void unblock(const Job& job);	// remove blocked job by reference
 
     FaxMachineInfo& getInfo(const fxStr& number);
     void updateConfig();		// write info file if necessary
 };
 
+inline u_int DestInfo::getActive() const	{ return activeCount; }
+inline u_int DestInfo::getBlocked() const	{ return blockedCount; }
+inline u_int DestInfo::getCount() const
+    { return activeCount + blockedCount; }
+inline bool DestInfo::isEmpty() const		{ return getCount() == 0; }
+inline u_int DestInfo::getCalls() const		{ return callCount; }
+inline void DestInfo::call()			{ callCount++; }
+inline void DestInfo::hangup()			{ callCount--; }
 
 fxDECLARE_StrKeyDictionary(DestInfoDict, DestInfo)
 #endif /* _DestInfo_ */
