@@ -1,4 +1,4 @@
-/*	$Id: FaxModem.h,v 1.45 2007/06/04 17:11:07 aidan Exp $ */
+/*	$Id: FaxModem.h,v 1.16 2008/11/24 06:17:59 faxguy Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -46,6 +46,10 @@ class FaxServer;
 typedef unsigned int RTNHandling;       // RTN signal handling method 
 typedef unsigned int BadPageHandling;	// bad page (received) handling method 
 typedef unsigned int JBIGSupport;	// JBIG support available
+typedef struct {
+    bool	senderSkipsV29;		// if sender skips V.29 usage
+    bool	senderHasV17Trouble;	// if we have trouble understanding sender's V.17
+} FaxSetup;
 
 /*
  * This is an abstract class that defines the interface to
@@ -63,12 +67,14 @@ private:
     u_int	pageNumber;	// current transmit page number
     u_int	pageNumberOfJob;// current transmit page number of Job
     u_int	pageNumberOfCall;// current transmit page number of call
+    u_int	noCountCoverPages; // number of no-count cover pages
     FaxFont*	tagLineFont;	// font for imaging tag line
     u_int	tagLineSlop;	// extra space reserved for tag line re-encoding
     fxStr	tagLine;	// tag line formatted with transmit time
+    fxStr	tagLineLocale;	// locale setting for tagline
     u_int	tagLineFields;	// number of fields in the tag line
 
-    void	setupTagLine(const FaxRequest&, const fxStr& tagLineFmt);
+    void	setupTagLine(const FaxRequest&, const fxStr& tagLineFmt, const fxStr& locale);
 // phase c data receive & copy quality checking
     u_int	cblc;		// current count of consecutive bad lines
     bool	lastRowBad;	// last decoded row was bad
@@ -88,9 +94,10 @@ private:
     pid_t	decoderPid;	// process id for the decoding process
     u_char	parserBuf[16];	// buffer used for parsing JBIG and JPEG
     u_long	parserCount[3];	// counters used in parsing JBIG and JPEG
+    int		imagefd;	// file descriptor for image file
 
-    void	flushEncodedData(TIFF*, tstrip_t, const u_char*, u_int);
-    void	flushRawData(TIFF*, tstrip_t, const u_char*, u_int);
+    void	flushEncodedData(TIFF*, tstrip_t, const u_char*, u_int, fxStr& emsg);
+    void	flushRawData(TIFF*, tstrip_t, const u_char*, u_int, fxStr& emsg);
     void	invalidCode(const char* type, int x);
     void	badPixelCount(const char* type, int got, int expected);
     void	badDecodingState(const char* type, int x);
@@ -125,7 +132,7 @@ protected:
     void	traceModemParams();
     void	traceFCF(const char* dir, u_int fcf);
     void	parseJPEGStream(u_char c);
-    void	fixupJPEG(TIFF* tif);
+    void	fixupJPEG(TIFF* tif, fxStr& emsg);
     void	parseJBIGStream(u_char c);
     void	parseJBIGBIH(u_char* buf);
     void	clearSDNORMCount();
@@ -133,7 +140,7 @@ protected:
     bool	getHDLCTracing();
     bool	getECMTracing();
     FaxSendStatus sendSetupParams(TIFF*, Class2Params&,
-		    FaxMachineInfo&, Status&);
+		    FaxMachineInfo&, fxStr&);
     void	recvTSI(const fxStr&);
     void	recvPWD(const fxStr&);
     void	recvSUB(const fxStr&);
@@ -144,14 +151,14 @@ protected:
     void	recvStartPage(TIFF* tif);
     void	recvResetPage(TIFF* tif);
     u_int	decodePageChop(const fxStr& pph, const Class2Params&);
-    bool	decodePPM(const fxStr& pph, u_int& ppm, Status& eresult);
+    bool	decodePPM(const fxStr& pph, u_int& ppm, fxStr& emsg);
     void	notifyPageSent(TIFF*);
 // phase c data receive & copy quality checking
     bool	recvPageDLEData(TIFF* tif, bool checkQuality,
-		    const Class2Params& params, Status& eresult);
+		    const Class2Params& params, fxStr& emsg);
     void	setupStartPage(TIFF* tif, const Class2Params& params);
     void	recvEndPage(TIFF* tif, const Class2Params& params);
-    void	writeECMData(TIFF*, u_char*, u_int, const Class2Params&, u_short);
+    void	writeECMData(TIFF*, u_char*, u_int, const Class2Params&, u_short, fxStr& emsg);
     void	resetLineCounts();
     void	initializeDecoder(const Class2Params&);
     virtual void abortPageRecv() = 0;
@@ -169,7 +176,7 @@ protected:
 /*
  * Correct if neccessary Phase C (T.4/T.6) data (remove extra RTC/EOFB etc.)
  */
-    int		correctPhaseCData(u_char* buf, u_long* pBufSize,
+    void	correctPhaseCData(u_char* buf, u_long& pBufSize,
                                   u_int fillorder, const Class2Params& params, uint32& rows);
 /*
  * Convert Phase C data...
@@ -219,6 +226,8 @@ public:
     u_int getBestScanlineTime() const;
     virtual int selectScanlineTime(int st) const;
 
+    u_int getNoCountCoverPages();
+
     u_int getVRes() const;
     u_int getBestDataFormat() const;
     u_int getBestPageWidth() const;
@@ -229,7 +238,7 @@ public:
     /*
      * Fax send protocol.  The expected sequence is:
      *
-     * if (faxService() && sendSetup(req, params, emsg) && dial(number, emsg) == OK) {
+     * if (faxService() && sendSetup(req, params, emsg) && dial(number, origin, emsg) == OK) {
      *	  sendBegin();
      *	  if (getPrologue() == send_ok and parameters acceptable) {
      *	     select send parameters
@@ -248,14 +257,13 @@ public:
      * single T.30 document.
      */
     virtual bool faxService(bool enableV34, bool enableV17) = 0;
-    virtual bool sendSetup(FaxRequest&, const Class2Params& dis, Status&
-		    eresult);
+    virtual bool sendSetup(FaxRequest&, const Class2Params& dis, fxStr& emsg);
     virtual void sendBegin();
     virtual FaxSendStatus getPrologue(Class2Params&,
-	bool& hasDoc, Status& eresult, u_int& batched) = 0;
+	bool& hasDoc, fxStr& emsg, u_int& batched) = 0;
     virtual void sendSetupPhaseB(const fxStr& pwd, const fxStr& sub);
     virtual FaxSendStatus sendPhaseB(TIFF*, Class2Params&, FaxMachineInfo&,
-	fxStr& pph, Status& eresult, u_int& batched) = 0;
+	fxStr& pph, fxStr& emsg, u_int& batched) = 0;
     virtual void sendEnd();
     virtual void sendAbort() = 0;
     // query interfaces for optional state
@@ -291,10 +299,10 @@ public:
      * }
      */
     virtual bool setupReceive() = 0;
-    virtual bool recvBegin(Status& eresult);
-    virtual bool recvEOMBegin(Status& eresult);
-    virtual bool recvPage(TIFF*, u_int& ppm, Status& result, const fxStr& id) = 0;
-    virtual bool recvEnd(Status& eresult) = 0;
+    virtual bool recvBegin(FaxSetup* setupinfo, fxStr& emsg);
+    virtual bool recvEOMBegin(FaxSetup* setupinfo, fxStr& emsg);
+    virtual bool recvPage(TIFF*, u_int& ppm, fxStr& em, const fxStr& id) = 0;
+    virtual bool recvEnd(FaxSetup* setupinfo, fxStr& emsg) = 0;
     virtual void recvAbort() = 0;
     virtual void recvSucceeded();
     virtual void pokeConfig(bool isSend) = 0;
@@ -319,9 +327,9 @@ public:
      *
      * (i.e. it's just like a receive operation.)
      */
-    virtual bool requestToPoll(Status& eresult) = 0;
+    virtual bool requestToPoll(fxStr& emsg) = 0;
     virtual bool pollBegin(
 	const fxStr& cig, const fxStr& sep, const fxStr& pwd,
-	Status& eresult);
+	fxStr& emsg);
 };
 #endif /* _FAXMODEM_ */
