@@ -1,4 +1,4 @@
-/*	$Id: FaxRequest.h,v 1.13 2007/06/04 17:11:07 aidan Exp $ */
+/*	$Id: FaxRequest.h,v 1.12 2008/09/14 10:33:12 faxguy Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -33,11 +33,8 @@
 #include <time.h>
 #include <stdio.h>
 
-#include "Status.h"
-
 class Class2Params;
 
-
 /*
  * This structure is passed from the queue manager
  * to the fax modem+protocol service for each job
@@ -101,6 +98,10 @@ public:
 	const char* name;
 	u_short FaxRequest::* p;
     };
+    struct intval {
+	const char* name;
+	int FaxRequest::* p;
+    };
 
     fxStr	qfile;		// associated queue file name
     fxStr	jobid;		// job identifier
@@ -111,8 +112,12 @@ public:
     u_short	state;		// job scheduling state
     u_short	lineno;		// line number when reading queue file
     FaxSendStatus status;	// request status indicator
-    u_short	totpages;	// total cummulative pages in documents
+    u_short	totpages;	// total cumulative pages in documents
     u_short	npages;		// total pages sent/received
+    u_short	skippages;	// skip over these pages in the document
+    int		skippedpages;	// start page numbering here + 1
+    u_short	serverdocover;	// server should create the coverpage
+    u_short	nocountcover;	// don't count these pages
     u_short	ntries;		// # tries to send current page
     u_short	ndials;		// # consecutive failed tries to call dest
     u_short	totdials;	// total # calls to dest
@@ -134,6 +139,7 @@ public:
     u_short	usexvres;	// whether to use extended VR
     u_short	pagechop;	// whether to do page chopping
     u_short	notify;		// email notification flags
+    u_short	ignoremodembusy;// ignore modem busy status
     float	chopthreshold;	// minimum white space before chopping
     time_t	tts;		// time to send
     time_t	killtime;	// time to kill job
@@ -144,9 +150,13 @@ public:
     fxStr	number;		// dialstring for fax machine
     fxStr	subaddr;	// transmit subaddress
     fxStr	passwd;		// transmit password
+    fxStr	canonical;	// canonical phone number for data correlation
     fxStr	external;	// displayable phone number for fax machine
-    fxStr	modem;		// outgoing modem to use
+    fxStr	notice;		// message to send for notification
+    fxStr	modem;		// outgoing modem (ModemGroup) to use
+    fxStr	modemused;	// specific modem used in last attempt
     fxStr	faxnumber;	// Sender's number to advertise to phone company
+    fxStr	faxname;	// Sender's name to advertise to phone company
     fxStr	tsi;		// TSI to use instead of LocalIdentifier
     fxStr	pagehandling;	// page analysis information
     fxStr	receiver;	// receiver's identity for cover page generation
@@ -167,14 +177,17 @@ public:
     fxStr	doneop;		// operation to do when job completes
     fxStr	csi;		// CSI string from receiving equipment (ASCII representation)
     fxStr	nsf;		// NSF string from receiving equipment (ASCII representation)
+    fxStr	timeofday;	// time of day restrictions
+    fxStr	errorcode;	// error code for status
     pid_t	writeQFilePid;	// pid of last writeQFile operation
     FaxItemArray items;	// set of requests
 
     static stringval strvals[];
     static shortval shortvals[];
-    static char* opNames[18];
-    static char* notifyVals[4];
-    static char* chopVals[4];
+    static intval intvals[];
+    static const char* opNames[18];
+    static const char* notifyVals[4];
+    static const char* chopVals[4];
 
     FaxRequest(const fxStr& qf, int fd = -1);
     virtual ~FaxRequest();
@@ -187,6 +200,7 @@ public:
 
     static bool isStrCmd(const char* cmd, u_int& ix);
     static bool isShortCmd(const char* cmd, u_int& ix);
+    static bool isIntCmd(const char* cmd, u_int& ix);
 
     void insertFax(u_int ix, const fxStr& file);
     void addItem(FaxSendOp op, char* tag);
@@ -197,14 +211,6 @@ public:
     static fxStr mkbasedoc(const fxStr& file);
     void renameSaved(u_int fi);
     bool isUnreferenced(u_int fi);
-
-    Status result;
-
-#if 0
-private:
-    fxStr	notice;		// message to send for notification
-    fxStr	code;		// code relating to notice
-#endif
 };
 inline bool FaxRequest::isNotify(u_int what) const
     { return (notify & (u_short) what) != 0; }
