@@ -1,4 +1,4 @@
-/*	$Id: FaxSendStatus.h,v 1.5 2007/05/04 17:28:32 aidan Exp $ */
+/*	$Id: FaxSendStatus.h,v 1.1.1.1 2005/11/11 21:32:02 faxguy Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -35,8 +35,7 @@ enum FaxSendStatus {
     send_reformat,		// retry with reformatted documents
     send_v34fail,		// failed due to V.34-Fax trouble
     send_v17fail,		// failed due to V.17-Fax trouble
-    send_batchfail,		// batch failure, retry
-    send_nobatch,		// Nothing happend to this job in the batch
+    send_batchfail		// batch failure, retry
 };
 #define	send_ok	send_done
 #endif /* _FaxSendStatus_ */
