@@ -1,4 +1,4 @@
-/*	$Id: FaxServer.h,v 1.20 2007/06/05 18:51:16 aidan Exp $ */
+/*	$Id: FaxServer.h,v 1.7 2008/01/12 20:00:18 faxguy Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -31,7 +31,6 @@
 #include "ModemServer.h"
 #include "FaxRecvInfo.h"
 #include "Array.h"
-#include "FaxRequest.h"
 
 class FaxAcctInfo;
 
@@ -61,6 +60,7 @@ private:
     time_t	pageTransferTime;	// transfer time for last page
     u_int	npages;			// # pages sent/received
     fxStr	batchid;		// Batch ID, for session logs
+    u_int	formatSize[2];		// combined byte sizes for comparing 1D and 2D encodings
 
     friend class FaxModem;
 
@@ -68,22 +68,23 @@ private:
 
 // FAX transmission protocol support
     void	sendFax(FaxRequest& fax, FaxMachineInfo&, const fxStr& number, u_int&);
-    bool	sendClientCapabilitiesOK(FaxRequest&, FaxMachineInfo&, Status& result);
+    bool	sendClientCapabilitiesOK(FaxRequest&, FaxMachineInfo&, fxStr&);
     bool	sendFaxPhaseB(FaxRequest&, FaxItem&, FaxMachineInfo&, u_int, bool);
     void	sendPoll(FaxRequest& fax, bool remoteHasDoc);
     FaxSendStatus sendSetupParams(TIFF*,
-		    Class2Params&, const FaxMachineInfo&, Status& result);
+		    Class2Params&, const FaxMachineInfo&, fxStr&);
     FaxSendStatus sendSetupParams1(TIFF*,
-		    Class2Params&, const FaxMachineInfo&, Status& result);
+		    Class2Params&, const FaxMachineInfo&, fxStr&);
     void	sendFailed(FaxRequest& fax,
-		    FaxSendStatus, const Status& result, u_int tts = 0);
+		    FaxSendStatus, const char* notice, u_int tts = 0);
 // FAX reception support
     int		getRecvFile(fxStr& qfile, fxStr& emsg);
-    TIFF*	setupForRecv(FaxRecvInfo&, FaxRecvInfoArray&, Status& eresult);
-    bool	recvDocuments(TIFF*, FaxRecvInfo&, FaxRecvInfoArray&, Status& eresult);
-    bool	recvFaxPhaseD(TIFF* tif, FaxRecvInfo&, u_int& ppm, Status& eresult);
+    TIFF*	setupForRecv(FaxRecvInfo&, FaxRecvInfoArray&, fxStr& emsg);
+    bool	recvDocuments(TIFF*, FaxRecvInfo&, FaxRecvInfoArray&,
+		    FaxSetup* setupinfo, fxStr& emsg);
+    bool	recvFaxPhaseD(TIFF* tif, FaxRecvInfo&, u_int& ppm, fxStr& emsg);
     bool	pollFaxPhaseB(const fxStr& sep, const fxStr& pwd,
-		    FaxRecvInfoArray&, Status& eresult);
+		    FaxRecvInfoArray&, fxStr& emsg);
 protected:
     FaxServer(const fxStr& deviceName, const fxStr& devID);
 
@@ -96,7 +97,7 @@ protected:
     void	setLocalIdentifier(const fxStr& lid);
 
     void	sendFax(FaxRequest&, FaxMachineInfo&, FaxAcctInfo&, u_int&, bool);
-    bool	recvFax(const CallID& callid, Status& eresult);
+    bool	recvFax(const CallID& callid, FaxMachineInfo clientInfo, fxStr& emsg);
 
     time_t	getFileTransferTime() const;
     time_t	getPageTransferTime() const;
@@ -115,6 +116,7 @@ protected:
     virtual void notifyPageRecvd(TIFF* tif, FaxRecvInfo&, int ppm);
     virtual void notifyDocumentRecvd(FaxRecvInfo& req);
     virtual void notifyRecvDone(FaxRecvInfo& req);
+    virtual bool processTSIRecvdCmd(FaxRecvInfo&, fxStr&);
 public:
     virtual ~FaxServer();
 
