@@ -1,4 +1,4 @@
-/*	$Id: JobControl.h,v 1.5 2007/06/05 18:51:16 aidan Exp $ */
+/*	$Id: JobControl.h,v 1.5 2007/12/05 02:13:53 faxguy Exp $ */
 /*
  * Copyright (c) 1994-1996 Sam Leffler
  * Copyright (c) 1994-1996 Silicon Graphics, Inc.
@@ -54,7 +54,9 @@ private:
     int		usexvres;		// use extended resolution
     u_int	vres;			// use extended resolution
     fxStr	args;			// arguments for subprocesses
+    int		priority;		// override submission priority with this
     int		desireddf;		// if set, desireddf value
+    int		notify;			// if set, notify value
 
     // default returned on no match
     static const JobControlInfo defControlInfo;
@@ -66,11 +68,6 @@ public:
     JobControlInfo(const JobControlInfo& other);
     ~JobControlInfo();
 
-
-    bool isCompatible (const JobControlInfo& other) const;
-
-    void parseEntry(const char* tag, const char* value, bool quoted);
-
     u_int getMaxConcurrentCalls() const;
     u_int getMaxSendPages() const;
     u_int getMaxDials() const;
@@ -80,12 +77,16 @@ public:
     time_t nextTimeToSend(time_t) const;
     int getUseXVRes() const;
     u_int getVRes() const;
+    int getPriority() const;
     int getDesiredDF() const;
+    int getNotify() const;
+    bool isNotify(u_int what) const;
     const fxStr& getArgs() const;
 
     virtual bool setConfigItem(const char*, const char*);
     virtual void configError(const char*, ...);
     virtual void configTrace(const char*, ...);
 };
+inline const fxStr& JobControlInfo::getArgs() const	{ return args; }
 
 #endif /* _JobControl_ */
