@@ -1,4 +1,4 @@
-/*	$Id: Modem.h,v 1.13 2007/05/04 17:32:12 aidan Exp $ */
+/*	$Id: Modem.h,v 1.7 2008/09/14 10:33:12 faxguy Exp $ */
 /*
  * Copyright (c) 1994-1996 Sam Leffler
  * Copyright (c) 1994-1996 Silicon Graphics, Inc.
@@ -75,7 +75,8 @@ public:
     enum {
 	DOWN  = 0,		// modem identified, but offline
 	READY = 1,		// modem ready for use
-	BUSY  = 2		// modem in use
+	BUSY  = 2,		// modem in use
+	EXEMPT = 3		// modem exempt from sending use
     };
 private:
     int		fd;		// cached open FIFO file
@@ -93,7 +94,6 @@ private:
     ModemLockWaitHandler lockHandler;
 
     static QLink list;		// list of all modems
-    static int modemsReady;	// count of ready modems
 
     void setCapabilities(const char*);	// specify modem capabilities
     void setNumber(const char*);	// specify modem phone number
@@ -108,13 +108,12 @@ public:
 
     static void CLEANUP (void);
 
-    static bool anyReady (void);
     static Modem& getModemByID(const fxStr& id);
-    static Modem* modemExists(const fxStr& id);
-    static Modem* findModem(const Job& job);
+    static Modem* modemExists(const fxStr& id, bool notexempt = false);
+    static Modem* findModem(const Job& job, bool ignorebusy);
     bool isInGroup(const fxStr& mgroup);
 
-    bool assign();			// assign modem
+    bool assign(Job&, bool ignorebusy);	// assign modem
     void release();			// release modem
 
     void startLockPolling(long sec);	// initiate polling thread
@@ -154,8 +153,6 @@ inline const Class2Params& Modem::getCapabilities() const { return caps; }
 inline u_int Modem::getPriority() const		{ return priority; }
 inline const fxStr& Modem::getCommID() const	{ return commid; }
 
-inline bool Modem::anyReady()			{ return modemsReady > 0; }
-
 /*
  * Modem iterator class; for iterating
  * over the set of known modems.
