@@ -1,4 +1,4 @@
-/*	$Id: ModemConfig.h,v 1.55 2007/06/05 17:30:16 aidan Exp $ */
+/*	$Id: ModemConfig.h,v 1.30 2008/04/29 21:12:20 faxguy Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -32,13 +32,16 @@
 #include "FaxModem.h"
 
 #include "Array.h"
-#include "StrArray.h"
 
 class id_config
 {
     public:
 	fxStr	pattern;
 	int	answerlength;
+	bool	display;
+	fxStr	label;
+	bool	record;
+	fxStr	type;
 
 	int compare (const id_config* n) const
 	{
@@ -84,6 +87,7 @@ public:
     fxStr	resetCmds;		// extra modem reset commands for start of initialization
     fxStr	readyCmds;		// extra modem reset commands for end of initialization
     fxStr	dialCmd;		// cmd for dialing (%s for number)
+    fxStr	setOriginCmd;		// cmd for setting the origination id (%s for name, %d for number)
     fxStr	answerAnyCmd;		// cmd for answering unknown call type
     fxStr	answerDataCmd;		// cmd for answering data call
     fxStr	answerFaxCmd;		// cmd for answering fax call
@@ -104,6 +108,7 @@ public:
     fxStr	onHookCmd;		// cmd for placing phone ``on hook''
     fxStr	softResetCmd;		// cmd for doing soft reset
     u_int	softResetCmdDelay;	// time in ms to pause after soft reset
+    u_int	noAutoAnswerCmdDelay;	// time in ms to pause after noAutoAnswerCmd
     u_int	ringsBeforeResponse;	// number of rings to wait before ModemRingResponse
     u_int	ringTimeout;		// timeout in ms after RING to reset
     fxStr	waitTimeCmd;		// cmd for setting carrier wait time
@@ -127,6 +132,7 @@ public:
     fxStr	dringOn;		// pattern for distinctive ring silence interval
     fxStr	dringOff;		// pattern for distinctive ring ring interval
     bool	noAnswerVoice;		// leave voice calls unanswered
+    bool	saverawimage;		// debugging feature to save raw image data
 					// call identification
     IDConfArray	idConfig;		// pattern for ID info
 					// protocol timers
@@ -156,11 +162,13 @@ public:
     u_int	class1TCFRecvTimeout;	// timeout receiving TCF
     u_int	class1RecvAbortOK;	// if non-zero, OK sent after recv abort
     u_int	class1RMPersistence;	// how many times to persist through +FCERROR
+    u_int	class1HookSensitivity;	// how many times to persist through on-hook detections
     u_int	class1Resolutions;	// resolutions support
     u_int	class1FrameOverhead;	// overhead bytes in received frames
     u_int	class1RecvIdentTimer;	// timeout receiving initial identity
     u_int	class1TCFMaxNonZero;	// non-zero threshold for TCF check
     u_int	class1TCFMinRun;	// min length of zero run for TCF check
+    u_int	class1TCFMinRunECMMod;	// modify min length in ECM by this factor
     u_int	class1TMConnectDelay;	// delay (ms) after +FTM CONNECT
     u_int	class1ECMFrameSize;	// ECM frame size for transmission
     u_int	class1PageLengthSupport;// page length support
@@ -172,14 +180,15 @@ public:
     bool	class1MMRSupport;	// support 2-D MMR
     bool	class1PersistentECM;	// continue to correct
     bool	class1ValidateV21Frames;// check received FCS values in V.21
-    bool	class1ModemHasDLEBug;;	// modem doesn't double-up DLEs in V.21
-    bool	class1HasRHConnectBug;;	// modem reports CONNECT after +FRH=3 to non-V.21-HDLC data
+    bool	class1ModemHasDLEBug;	// modem doesn't double-up DLEs in V.21
+    bool	class1HasRHConnectBug;	// modem reports CONNECT after +FRH=3 to non-V.21-HDLC data
 					// for class 2 and 2.0:
     fxStr	class2Cmd;		// cmd for setting Class 2/2.0
     fxStr	class2DCCQueryCmd;	// cmd to query modem capabilities
     fxStr	class2CQQueryCmd;	// cmd to query copy quality checking
     fxStr	class2BORCmd;		// cmd to set bit order
     fxStr	class2DisableV17Cmd;	// cmd to disable V.17 support
+    fxStr	class2DisableV34Cmd;	// cmd to disable V.34 support
     fxStr	class2RELCmd;		// cmd to enable byte-aligned EOL
     fxStr	class2CQCmd;		// cmd to setup copy quality checking
     fxStr	class2AbortCmd;		// cmd to abort a session
@@ -229,21 +238,25 @@ public:
     u_int	atCmdDelay;		// delay (ms) between each AT cmd
     u_int	percentGoodLines;	// required % of good lines in page
     u_int	maxConsecutiveBadLines;	// max consecutive bad lines in page
+    u_int	minAcceptedLineCount;	// min accepted number of lines in page
     u_int	minSpeed;		// minimum speed for fax transmits
     bool	softRTFCC;		// real-time fax compression conversion (software)
     bool	waitForConnect;		// modem sends multiple answer responses
     fxStr	tagLineFmt;		// format string for tag lines
+    fxStr	tagLineLocale;		// locale for tag lines
     fxStr	tagLineFontFile;	// font file for imaging tag lines
     u_int	recvDataFormat;		// received facsimile data format
     bool	useJobTagLine;		// Use Job tagline or use conf taglineformat
+    bool	raiseATCmd;		// whether or not to raise-case the AT commands
+    bool	doPhaseCDebug;		// Query modem during Phase C for debugging info.
 
     RTNHandling rtnHandling;            // RTN signal handling method
     BadPageHandling badPageHandling;	// bad page (received) handling method
     JBIGSupport	class1JBIGSupport;	// monochrome JBIG support
+    JBIGSupport	class2JBIGSupport;	// monochrome JBIG support
     bool	saveUnconfirmedPages;	// don't delete unconfirmed pages
+    fxStr	tiff2faxCmd;		// for intelligent RTFCC in comparing compression rates
     
-    fxStrArray	playList;		// List of files for ESC_PLAY
-
     					// Distinctive ring data as sequences of DRON/DROF intervals
     struct {
     	int cadence[5];                 // the ring cadence as a five-dimensional vector
