@@ -1,4 +1,4 @@
-/*	$Id: ModemServer.h,v 1.15 2007/06/04 17:11:07 aidan Exp $ */
+/*	$Id: ModemServer.h,v 1.6 2007/07/11 00:27:25 faxguy Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -139,7 +139,7 @@ protected:
     void	timerExpired(long, long);
     void	sendDLEETX();
     int		getModemLine(char buf[], u_int bufSize, long ms = 0);
-    int		getModemChar(long ms = 0);
+    int		getModemChar(long ms = 0, bool isquery = false);
     int		getModemBit(long ms = 0);
     int		getLastByte();
     bool	didBlockEnd();
@@ -161,12 +161,12 @@ protected:
     bool	modemStopOutput();
 // modem driver interfaces
     bool	modemWaitForRings(u_short rings, CallType&, CallID&);
-    CallType	modemAnswerCall(AnswerType, Status& eresult, const char* dialnumber = NULL);
+    CallType	modemAnswerCall(AnswerType, fxStr&, const char* dialnumber = NULL);
     void	modemAnswerCallCmd(CallType);
     void	modemFlushInput();
     void	modemHangup();
 // server state and related control interfaces
-    void	changeState(ModemServerState, long timeout = 0);
+    void	changeState(ModemServerState, long timeout = 0, const char* msg = NULL);
     void	setServerStatus(const char* fmt, ...);
     void	setProcessPriority(ModemServerState s);
 // system logging interfaces
@@ -195,6 +195,8 @@ protected:
     virtual void abortSession();
     bool	abortRequested();
 public:
+    const char* readyStateMsg;
+
     virtual ~ModemServer();
 
     virtual void open();
