@@ -1,4 +1,4 @@
-/*	$Id: faxQueueApp.h,v 1.36.2.1 2007/12/11 15:48:00 aidan Exp $ */
+/*	$Id: faxQueueApp.h,v 1.13 2008/09/14 10:33:13 faxguy Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -32,7 +32,6 @@
 #include "FaxConfig.h"
 #include "IOHandler.h"
 #include "Job.h"
-#include "Batch.h"
 #include "DestInfo.h"
 #include "JobControl.h"
 #include "StrDict.h"
@@ -45,7 +44,6 @@ class UUCPLock;
 class FaxItem;
 class Modem;
 class Trigger;
-class Status;
 
 /*
  * This class represents a thread of control that manages the
@@ -67,12 +65,9 @@ public:
 	u_int faxQueueApp::*p;
 	u_int		 def;
     };
-    struct booltag {
-	const char*	 name;
-	bool faxQueueApp::*p;
-	bool		 def;
-    };
 private:
+    time_t	lastCall;		// time of last call
+
     class SchedTimeout : public IOHandler {
     private:
 	bool	started;
@@ -105,12 +100,14 @@ private:
     mode_t	uucpLockMode;		// UUCP lock file creation mode
     u_int	uucpLockTimeout;	// UUCP stale lock file timeout
     u_int	pollLockWait;		// polling interval in lock wait state
+    u_int	staggerCalls;		// time to wait between initiating calls
     u_int	tracingLevel;		// tracing level w/o session
     u_int	tracingMask;		// tracing level control mask
     fxStr	logFacility;		// syslog facility to direct trace msgs
     u_int	requeueInterval;	// job requeue interval
     bool	use2D;			// ok to use 2D-encoded data
     bool	useUnlimitedLN;		// ok to use unlimited page length
+    bool	allowIgnoreModemBusy;	// to allow job to ignore modem busy status
     u_int	pageChop;		// default page chop handling
     float	pageChopThreshold;	// minimum space before page chop
     fxStr	notifyCmd;		// external command for notification
@@ -127,23 +124,21 @@ private:
 
     static stringtag strings[];
     static numbertag numbers[];
-    static booltag booleans[];
 // runtime state
     bool	timeout;		// timeout occurred
     bool	abortPrepare;		// job preparation should be aborted
     bool	quit;			// terminate server
     int		fifo;			// fifo job queue interface
-    QLink	runq;			// list of DestInfo ready to run
-    QLink	destq;			// list of DestInfo with no ready jobs
-    QLink	batchq;			// batches actively being processed
+#define	NQHASH		16
+    QLink	runqs[NQHASH];		// jobs ready to run
+    QLink	sleepq;			// jobs waiting for time-to-send
+    QLink	activeq;		// jobs actively being processed
     QLink	deadq;			// jobs waiting to be reaped
     QLink	suspendq;		// jobs suspending from scheduling
-    QLink	jcontrolq;		// jobs actively running jobcontrol
-    QLink	pendq;			// jobs pending future tts
     SchedTimeout schedTimeout;		// timeout for running scheduler
     DestInfoDict destJobs;		// jobs organized by destination
     fxStrDict	pendingDocs;		// documents waiting for removal
-    bool	inSchedule;
+    bool	inSchedule;		// indicates processing of runScheduler
 
     static faxQueueApp* _instance;
 
@@ -153,8 +148,9 @@ private:
 
     friend class JobTTSHandler;		// for access to runJob
     friend class JobKillHandler;	// for acccess to timeoutJob
+    friend class JobPrepareHandler;	// for acccess to prepareJobDone
+    friend class JobSendHandler;	// for acccess to sendJobDone
     friend class JobCtrlHandler;	// for acccess to ctrlJobDone
-    friend class Batch;			// for acccess to prepareDone and senddone
     friend class faxQueueApp::SchedTimeout;// for access to runScheduler
     friend class ModemLockWaitHandler;	// for access to pollForModemLock
 
@@ -168,15 +164,14 @@ private:
     fxStr	canonicalizePhoneNumber(const fxStr& ds);
 // modem support
     void	scanForModems();
-    bool	assignModem(Job& job);
-    void	releaseModem(Modem& modem);
+    bool	assignModem(Job& job, bool ignorebusy);
+    void	releaseModem(Job& job);
     void	notifyModemWedged(Modem&);
     void	pollForModemLock(Modem& modem);
 // diagnostic and tracing interfaces
     void	traceServer(const char* fmt ...);
     void	vtraceServer(const char* fmt, va_list ap);
     void	jobError(const Job& job, const char* fmt ...);
-    void	traceQueue(const DestInfo&, const char* fmt ...);
     void	traceQueue(const Job&, const char* fmt ...);
     void	traceJob(const Job&, const char* fmt ...);
     void	traceQueue(const char* fmt ...);
@@ -184,7 +179,9 @@ private:
 // miscellaneous stuff
     void	startTimeout(long ms);
     void	stopTimeout(const char* whichdir);
-    const fxStr& pickCmd(const fxStr& jobtype);
+    const fxStr& pickCmd(const FaxRequest& req);
+    void	blockSignals();
+    void	releaseSignals();
 // FIFO-related stuff
     void	childStatus(pid_t, int);	// Dispatcher hook
     int		inputReady(int);		// Dispatcher hook
@@ -206,41 +203,36 @@ private:
 		    bool force, const char* duration = "");
     void	notifySender(Job&, JobStatus, const char* = "");
 // job management interfaces
-    bool	isJobSendOK(Job& job, FaxRequest* req);
     void	processJob(Job& job);
-    void	processJob(Batch&, Job&, FaxRequest* req);
+    void	processJob(Job&, FaxRequest* req, DestInfo& di);
+    void	sendJobStart(Job&, FaxRequest*);
+    void	sendJobDone(Job& job, int status);
     void	sendJobDone(Job& job, FaxRequest* req);
-    void	doneJob(Job& job);
-    void	blockJob(Job&, FaxRequest&, const Status&);
-    void	delayJob(Job&, FaxRequest&, const Status&, time_t);
-    void	rejectJob(Job& job, FaxRequest& req, const Status&);
-    bool	submitJob(const fxStr& jobid, bool checkState = false);
+    void	blockJob(Job&, FaxRequest&, const char*);
+    void	delayJob(Job&, FaxRequest&, const char*, time_t);
+    void	rejectJob(Job& job, FaxRequest& req, const fxStr& reason);
+    bool	submitJob(const fxStr& jobid, bool checkState = false, bool nascent = false);
     bool	suspendJob(const fxStr& jobid, bool abortActive);
-    void	rejectSubmission(Job&, FaxRequest&, const Status&);
+    void	rejectSubmission(Job&, FaxRequest&, const fxStr& reason);
+    bool	areBatchable(FaxRequest& reqa, FaxRequest& reqb, Job& job, Job& cjob);
 
-    void	startBatch(Modem*, Job&, FaxRequest*, DestInfo&);
-    void	fillBatch (Batch&);
-    bool	canJobBatch(Batch& batch, Job& job, FaxRequest* req);
-
-    void	sendStart(Batch&);
-    void	sendDone(Batch&, int status);
-
-    void	setReadyToRun(Job& job, FaxRequest& req);
-    void	setReady(Job& job, FaxRequest& req);
+    void	setReadyToRun(Job& job, bool wait);
     void	setSleep(Job& job, time_t tts);
     void	setDead(Job& job);
-    void	setActive(Batch& batch, Job& job);
-    void	setPending(Job& job);
+    void	setActive(Job& job);
     void	setSuspend(Job& job);
     bool	submitJob(FaxRequest&, bool checkState = false);
     bool	submitJob(Job& job, FaxRequest& req, bool checkState = false);
     bool	suspendJob(Job& job, bool abortActive);
     bool	terminateJob(const fxStr& filename, JobStatus why);
-    void	timeoutAccounting(Job& job, FaxRequest&);
+    void	queueAccounting(Job& job, FaxRequest&, const char* type);
     void	timeoutJob(Job& job);
     void	timeoutJob(Job& job, FaxRequest&);
     void	runJob(Job& job);
 
+    void	removeDestInfoJob(Job& job);
+    void        unblockDestJobs(DestInfo& di);
+
     bool	scheduling();
     void	runScheduler();
     void	pokeScheduler(u_short s = 0);
@@ -249,20 +241,21 @@ private:
 // job preparation stuff
     bool	prepareJobNeeded(Job&, FaxRequest&, JobStatus&);
     static void prepareCleanup(int s);
-    void	prepareStart(Batch&, Job&, FaxRequest*);
-    void	prepareDone(Batch&, int status);
+    bool	prepareJobStart(Job&, FaxRequest*,
+		    FaxMachineInfo&);
+    void	prepareJobDone(Job&, int status);
     JobStatus	prepareJob(Job& job, FaxRequest& req,
 		    const FaxMachineInfo&);
     JobStatus	convertDocument(Job&,
 		    const FaxItem& input, const fxStr& outFile,
 		    const Class2Params& params,
-		    Status&);
+		    fxStr& emsg);
     JobStatus	runConverter(Job& job, const char* app, char* const* argv,
-		    Status&);
+		    fxStr& emsg);
     bool	runConverter1(Job& job, int fd, fxStr& output);
-    void	makeCoverPage(Job&, FaxRequest&, const Class2Params&);
+    bool	makeCoverPage(Job&, FaxRequest&, const Class2Params&);
     bool	preparePageHandling(Job&, FaxRequest&,
-		    const FaxMachineInfo&, Status&);
+		    const FaxMachineInfo&, fxStr& emsg);
     void	preparePageChop(const FaxRequest&,
 		    TIFF*, const Class2Params&, fxStr&);
     void	setupParams(TIFF*, Class2Params&, const FaxMachineInfo&);
