@@ -1,4 +1,4 @@
-/*	$Id: HylaFAXServer.h,v 1.20 2007/06/04 17:12:02 aidan Exp $ */
+/*	$Id: HylaFAXServer.h,v 1.23 2008/10/12 04:15:56 faxguy Exp $ */
 /*
  * Copyright (c) 1995-1996 Sam Leffler
  * Copyright (c) 1995-1996 Silicon Graphics, Inc.
@@ -40,6 +40,21 @@
 
 #include "config.h"
 
+#ifdef HAVE_PAM
+extern "C" {
+#include <security/pam_appl.h>
+#include <grp.h>
+}
+#endif // HAVE_PAM
+
+#ifdef HAVE_LDAP
+#include <ldap.h>
+#include <string.h>
+#include <stdlib.h>
+#include <sys/time.h>
+#include <lber.h>
+#endif // HAVE_LDAP
+
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <dirent.h>
@@ -74,6 +89,24 @@ struct RecvInfo : public FaxRecvInfo {
 };
 fxDECLARE_StrKeyDictionary(RecvInfoDict, RecvInfo*)
 
+#define HAVE_PSLEVEL2   false
+  
+static struct {
+    const char* name;		// protocol token name
+    bool        supported;	// true if format is supported
+    const char* suffix;		// file suffix
+    FaxSendOp	op;		// associated FaxSendOp value
+    const char* help;		// help string for HELP FORM command
+} formats[] = {
+{ "TIFF", true,          "tif", FaxRequest::send_tiff,		"Tagged Image File Format, Class F only" },
+{ "PS",   true,          "ps",  FaxRequest::send_postscript,	"Adobe PostScript" },
+{ "PS2",  HAVE_PSLEVEL2, "ps",  FaxRequest::send_postscript,	"Adobe PostScript Level II" },
+{ "PCL",  true,          "pcl", FaxRequest::send_pcl,		"HP Printer Control Language (PCL)"},
+{ "PDF",  true,          "pdf", FaxRequest::send_pdf,		"Adobe Portable Document Format" },
+};
+
+#define N(a)    (sizeof (a) / sizeof (a[0]))
+
 #ifdef T_USER
 #undef T_USER				// XXX FreeBSD defines this
 #endif
@@ -94,7 +127,7 @@ enum Token {
     T_ALLO,	 T_ANSWER,	T_APPE,		T_CHMOD,	T_CHOWN,
     T_CONFIG,	 T_CWD, 	T_CDUP,		T_DELE,		T_DELUSER,
     T_DELMODEM,	 T_DISABLE,	T_ENABLE,	T_FILEFMT,	T_FORM,
-    T_HELP,	 T_IDLE,	T_JDELE,	T_JGDELE,	T_JGINTR,
+    T_HELP,	 T_IDLE,	T_LOCKWAIT,	T_JDELE,	T_JGDELE,	T_JGINTR,
     T_JGKILL,	 T_JGNEW,	T_JGPARM,	T_JGREST,	T_JGRP,
     T_JGSUB,	 T_JGSUSP,	T_JGWAIT,	T_JINTR,	T_JKILL,
     T_JNEW,	 T_JOB,		T_JOBFMT,	T_JPARM,	T_JREST,
@@ -110,16 +143,16 @@ enum Token {
      */
     T_ACCTINFO,	 T_BEGBR,	T_BEGST,	T_CHOPTHRESH,	T_CLIENT,
     T_COMMENTS,	 T_COMMID,	T_COVER,	T_DATAFORMAT,	T_DIALSTRING,
-    T_DOCUMENT,	 T_DONEOP,	T_EXTERNAL,	T_FAXNUMBER,	T_FROM_COMPANY,	T_FROM_LOCATION,
-    T_FROM_USER, T_FROM_VOICE,	T_GROUPID,	T_HRES,		T_JOBID,
+    T_DOCUMENT,	 T_DONEOP,	T_EXTERNAL,	T_FAXNUMBER,	T_FAXNAME,	T_FROM_COMPANY,	T_FROM_LOCATION,
+    T_FROM_USER, T_FROM_VOICE,	T_GROUPID,	T_HRES,		T_IGNOREMODEMBUSY, T_JOBID,
     T_JOBINFO,	 T_JOBTYPE,	T_LASTTIME,	T_MAXDIALS,	T_MAXPAGES,
     T_MAXTRIES,	 T_MINBR,	T_MODEM,	T_NDIALS,	T_NOTIFY,
     T_NOTIFYADDR,T_NPAGES,	T_NTRIES,	T_OWNER,	T_PAGECHOP,
     T_PAGELENGTH,T_PAGEWIDTH,	T_PASSWD,	T_POLL,		T_REGARDING,
-    T_RETRYTIME, T_SCHEDPRI,	T_SENDTIME,	T_STATE,	T_STATUS,	T_STATUSCODE, T_ERRORCODE,
-    T_SUBADDR,	 T_TAGLINE,	T_TOTDIALS,	T_TOTPAGES,	T_TOTTRIES,
-    T_TO_COMPANY,T_TO_LOCATION,	T_TO_USER,	T_TO_VOICE,	T_TSI,		T_USE_CONTCOVER,
-    T_USE_ECM,	 T_USE_TAGLINE,	T_USE_XVRES,	T_USRKEY,	T_VRES,
+    T_RETRYTIME, T_SCHEDPRI,	T_SENDTIME,	T_SKIPPAGES,	T_SKIPPEDPAGES,	T_STATE,	T_STATUS,	T_ERRORCODE,
+    T_SUBADDR,	 T_TAGLINE,	T_TIMEOFDAY,	T_TOTDIALS,	T_TOTPAGES,	T_TOTTRIES,
+    T_TO_COMPANY,T_TO_LOCATION,	T_TO_USER,	T_TO_VOICE,	T_TSI,		T_USE_CONTCOVER, T_NOCOUNTCOVER, T_SERVERDOCOVER,
+    T_USE_ECM,	 T_ECMTYPE,	T_USE_TAGLINE,	T_USE_XVRES,	T_USRKEY,	T_VRES,
     /*
      * SNPP tokens.
      */
@@ -165,6 +198,7 @@ public:
         u_int HylaFAXServer::*p;
         u_int		 def;
     };
+    static int _debugSleep;
 protected:
     u_int	state;
 #define	S_LOGGEDIN	0x0001		// client is logged in
@@ -192,6 +226,8 @@ protected:
     fxStr	fifoResponse;		// response received to FIFO msg
     u_int	idleTimeout;		// client inactivity timeout
     u_int	maxIdleTimeout;		// upper bound on idle timeout
+    u_int	lockTimeout;		// qfile lock timeout
+    u_int	maxLockTimeout;		// upper bound on qfile lock timeout
     int		data;			// current data connection (socket)
     int		pdata;			// passive mode data connect (socket)
     fxStr	hostname;		// name of machine server is running on
@@ -206,18 +242,30 @@ protected:
     time_t	discTime;		// time to disconnect service
     time_t	denyTime;		// time to deny service
     u_int	jobProtection;		// Protection to use on Jobs
+    u_int	recvqProtection;	// Protection to use on Recvq
     /*
      * User authentication and login-related state.
      */
-    fxStr	passwd;			// encrypted user password
-    fxStr	adminwd;		// encrypted passwd for admin privileges
+#ifdef HAVE_PAM
+	bool	pam_chrooted;	// if already chrooted, PAM gets disabled
+#endif
+
+    fxStr	passWd;			// encrypted user password
+    fxStr	adminWd;		// encrypted passwd for admin privileges
+#ifdef HAVE_LDAP
+    fxStr	ldapServerUri;		// URL for the LDAP Server
+    fxStr	ldapBaseDN;		// LDAP base DN where user objects are found
+    fxStr	ldapReqGroup;		// LDAP group users need to be members of for
+					// fax server access
+    u_int	ldapVersion;		// LDAP Protocol Version being used (def. v3)
+#endif
     u_int	uid;			// client's ID
     u_int	loginAttempts;		// number of failed login attempts
     u_int	maxLoginAttempts;	// login failures before server exits
     u_int	adminAttempts;		// number of failed admin attempts
     u_int	maxAdminAttempts;	// admin failures before server exits
     fxStr	the_user;		// name of user
-    fxStr	admingroup;			// name of local user group that is allowed
+	fxStr   admingroup;			// name of local user group that is allowed
 								// to administer the fax server
     IDCache*	idcache;		// fax UID -> name mapping table
     /*
@@ -337,18 +385,14 @@ protected:
     void setFileOwner(const char* filename);
 
     void loginRefused(const char* why);
-
+    bool pamCheck(const char* user=NULL, const char* pass=NULL);
+    bool pamIsAdmin(const char* user=NULL);
+#ifdef HAVE_PAM
+    void pamEnd(pam_handle_t *pamh, int pamret);
+#endif
     bool checkUser(const char*);
-    bool checkPasswd(const char*);
-
-    bool checkuserHosts(FILE*, const char *name);
-    bool checkuserPAM(const char *name);
-
-    bool checkpasswdHosts(const char* passwd);
-    bool checkpasswdPAM(const char* passwd);
-
-    bool isAdminGroup(const char* user=NULL);
-
+    bool checkuser(FILE*, const char *name);
+    bool checkuser(const char *name);
     void login(int code);
     void end_login(void);
     virtual void dologout(int status);
@@ -356,7 +400,7 @@ protected:
     const char* userName(u_int uid);
     bool userID(const char*, u_int& id);
     void fillIDCache(void);
-
+    bool ldapCheck(const char* user, const char* pass);
     bool cvtPasswd(const char* type, const char* pass, fxStr& result);
     bool findUser(FILE* db, const char* user, u_int& newuid);
     bool addUser(FILE* db, const char* user, u_int uid,
@@ -379,6 +423,8 @@ protected:
 
     static SpoolDir dirs[];
 
+    bool checkFileRights(int op, const struct stat&);
+
     void dirSetup(void);
     static SpoolDir* dirLookup(const char* path);
     static SpoolDir* dirLookup(ino_t ino);
@@ -434,6 +480,7 @@ protected:
     bool cmd(Token t);
     bool site_cmd(Token t);
     bool param_cmd(Token t);
+    bool multi_string_param(fxStr&, const char* what = NULL);
     bool string_param(fxStr&, const char* what = NULL);
     bool number_param(long&);
     bool boolean_param(bool&);
@@ -454,7 +501,7 @@ protected:
     bool checkNUMBER(const char* s);
     bool opt_CRLF();
     bool opt_STRING(fxStr& s);
-    bool multi_STRING(fxStr& s);
+    bool multi_STRING(fxStr& s, const char* what = NULL);
     static u_int twodigits(const char* cp, u_int range);
     static u_int fourdigits(const char* cp);
     virtual void syntaxError(const char* msg);
@@ -545,9 +592,6 @@ protected:
     bool lockJob(Job& job, int how, fxStr& emsg);
     bool lockJob(Job& job, int how);
     void unlockJob(Job& job);
-#ifdef OLDPROTO_SUPPORT
-    void readJobs(void);
-#endif
     void purgeJobs(void);
     void jstatCmd(const Job&);
     void jstatLine(Token t, const char* fmt ...);
@@ -592,7 +636,7 @@ inline void HylaFAXServer::pushToken(Token t)		{ pushedToken = t; }
  * business seeing.  Also we implement an access
  * control system that is built on top of the
  * normal UNIX protection mechanisms.
- */ 
+ */
 struct SpoolDir {
     const char*	pathname;
     bool adminOnly;	// accessible by unprivileged clients
