@@ -1,4 +1,4 @@
-/*	$Id: FaxClient.h,v 1.8 2006/05/31 12:49:14 aidan Exp $ */
+/*	$Id: FaxClient.h,v 1.9 2008/03/12 05:43:09 faxguy Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -60,6 +60,7 @@ public:
         MODE_Z = 4		// zlib compressed
     };
     enum {			// data file FORMats
+        FORM_UNKNOWN = 0,	// unknown, initial setting
         FORM_PS   = 1,		// PostScript Level I
         FORM_PS2  = 2,		// PostScript Level II
         FORM_TIFF = 3,		// TIFF
@@ -111,6 +112,7 @@ private:
     int		fdData;		// data transfer connection
     char	buf[1024];	// input buffer
     int		code;		// code from last server repsonse
+    bool	pasv;		// use of passive mode
     fxStr	proto;		// protocol to use for service query
     fxStr	lastResponse;	// text message from last server response
     fxStr	lastContinuation; // continuation message from last server response
@@ -189,7 +191,8 @@ public:
     virtual bool callServer(fxStr& emsg);
     virtual bool hangupServer(void);
     bool isConnected(void) const;
-    bool login(const char* user, fxStr& emsg);
+    bool isPassive(void) const;
+    bool login(const char* user, const char* pass, fxStr& emsg);
     bool admin(const char* pass, fxStr& emsg);
     virtual const char* getPasswd(const char* prompt);
     bool isLoggedIn(void) const;
@@ -214,7 +217,7 @@ public:
 
     // output
     int command(const char* fmt ...);
-    int vcommand(const char* fmt, va_list ap);
+    int vcommand(const char* fmt, va_list ap1, va_list ap2);
     int getReply(bool expectEOF);
     const fxStr& getLastResponse(void) const;
     const fxStr& getLastContinuation(void) const;
@@ -328,6 +331,7 @@ inline int FaxClient::getLastCode(void) const		{ return code; }
 inline bool FaxClient::isLoggedIn(void) const
     { return (state&FS_LOGGEDIN) != 0; }
 inline bool FaxClient::isConnected(void) const	{ return fdIn != NULL; }
+inline bool FaxClient::isPassive(void) const	{ return pasv; }
 inline u_int FaxClient::getType(void) const		{ return type; }
 inline u_int FaxClient::getStruct(void) const		{ return stru; }
 inline u_int FaxClient::getMode(void) const		{ return mode; }
