@@ -1,4 +1,4 @@
-/*	$Id: SNPPClient.h,v 1.3 2002/06/15 18:00:12 darren Exp $ */
+/*	$Id: SNPPClient.h,v 1.6 2008/03/12 05:43:09 faxguy Exp $ */
 /*
  * Copyright (c) 1995-1996 Sam Leffler
  * Copyright (c) 1995-1996 Silicon Graphics, Inc.
@@ -70,6 +70,7 @@ private:
     FILE*	fdOut;		// control stream output handle
     char	buf[1024];	// input buffer
     int		code;		// code from last server repsonse
+    bool	pasv;		// whether or not to use passive mode
     fxStr	proto;		// protocol to use for service query
     fxStr	lastResponse;	// text message from last server response
     u_int	port;		// server port to connect to
@@ -162,7 +163,7 @@ public:
     virtual bool callServer(fxStr& emsg);
     virtual bool hangupServer(void);
     bool isConnected(void) const;
-    bool login(const char* user, fxStr& emsg);
+    bool login(const char* user, const char* pass, fxStr& emsg);
     virtual const char* getPasswd(const char* prompt);
     bool isLoggedIn(void) const;
     void setCtrlFds(int in, int out);
@@ -180,7 +181,7 @@ public:
 
     // output
     int command(const char* fmt ...);
-    int vcommand(const char* fmt, va_list ap);
+    int vcommand(const char* fmt, va_list ap1, va_list ap2);
     int getReply(bool expectEOF);
     const fxStr& getLastResponse(void) const;
     int getLastCode(void) const;
