@@ -1,4 +1,4 @@
-/*	$Id: SendFaxJob.h,v 1.8 2005/05/09 14:57:49 aidan Exp $ */
+/*	$Id: SendFaxJob.h,v 1.8 2008/09/14 10:33:17 faxguy Exp $ */
 /*
  * Copyright (c) 1993-1996 Sam Leffler
  * Copyright (c) 1993-1996 Silicon Graphics, Inc.
@@ -77,6 +77,8 @@ private:
     fxStr	subaddr;		// subaddress for routing (opt)
     fxStr	passwd;			// password (opt)
     fxStr	external;		// displayable version of number (opt)
+    fxStr	faxnumber;		// originating number for setting Caller*ID Number
+    fxStr	faxname;		// originating name for setting Caller*ID Name
 
     bool	autoCover;		// if true, auto-generate cover sheet
     bool	coverIsTemp;		// if true, remove coverFile on exit
@@ -114,6 +116,11 @@ private:
     u_int	desireddf;		// data format to use
     FaxPageChop	pagechop;		// page chop handling
     float	chopthreshold;		// white space threshold for chopping
+    u_int	skippages;		// skip these pages
+    u_int	skippedpages;		// begin page count at this page number + 1
+    u_int	nocountcover;		// don't include these pages in the page count
+    bool	serverdocover;		// server should generate the cover page
+    bool	ignoremodembusy;	// ignore modem busy status
 
     static SFJ_stringtag strings[];
     static SFJ_numbertag numbers[];
@@ -125,6 +132,7 @@ public:
     SendFaxJob(const SendFaxJob& other);
     virtual ~SendFaxJob();
 
+    virtual bool initJobs(SendFaxClient& client, fxStr& emsg);
     virtual bool createJob(SendFaxClient& client, fxStr& emsg);
 
     virtual void setupConfig();
@@ -183,6 +191,8 @@ public:
     const fxStr& getPasswd() const;
     void setExternalNumber(const char*);// displayable version of fax number
     const fxStr& getExternalNumber() const;
+    void setFaxNumber(const char*);	// Caller*ID Number, also tagline
+    void setFaxName(const char*);	// Caller*ID Name
 
     /*
      * Cover page support.
@@ -252,8 +262,9 @@ public:
     void setDesiredMST(int);		// desired/initial min-scanline time
     void setDesiredMST(const char* v);
     int getDesiredMST() const;
-    void setDesiredEC(bool b);	// desired use of Error Correction mode
-    bool getDesiredEC() const;
+    void setDesiredEC(int e);		// desired use of Error Correction mode
+    void setDesiredEC(const char* e);
+    int getDesiredEC() const;
     void setUseXVRes(bool b);		// desired use of extended resolutions
     bool getUseXVRes() const;
     void setDesiredDF(int);		// desired data format
@@ -268,6 +279,16 @@ public:
     u_int getChopHandling() const;
     void setChopThreshold(float);	// threshold (inches) for page chopping
     float getChopThreshold() const;
+    void setSkipPages(u_int);		// skip these pages
+    u_int getSkipPages() const;
+    void setSkippedPages(u_int);	// start page count here + 1
+    u_int getSkippedPages() const;
+    void setNoCountCover(u_int);	// don't include these pages in counts
+    u_int getNoCountCover() const;
+    void setServerDoCover(bool);	// server should generate cover page
+    bool getServerDoCover() const;
+    void setIgnoreModemBusy(bool);	// ignore modem busy status
+    bool getIgnoreModemBusy() const;
 };
 
 fxDECLARE_ObjArray(SendFaxJobArray, SendFaxJob)
@@ -309,10 +330,15 @@ inline float SendFaxJob::getHResolution() const		{ return hres; }
 inline int SendFaxJob::getMinSpeed() const		{ return minsp; }
 inline int SendFaxJob::getDesiredSpeed() const		{ return desiredbr; }
 inline int SendFaxJob::getDesiredMST() const		{ return desiredst; }
-inline bool SendFaxJob::getDesiredEC() const		{ return desiredec; }
+inline int SendFaxJob::getDesiredEC() const		{ return desiredec; }
 inline bool SendFaxJob::getUseXVRes() const		{ return useXVRes; }
 inline int SendFaxJob::getDesiredDF() const		{ return desireddf; }
 inline const fxStr& SendFaxJob::getTagLineFormat() const{ return tagline; }
 inline u_int SendFaxJob::getChopHandling() const	{ return pagechop; }
 inline float SendFaxJob::getChopThreshold() const	{ return chopthreshold; }
+inline u_int SendFaxJob::getSkipPages() const		{ return skippages; }
+inline u_int SendFaxJob::getSkippedPages() const	{ return skippedpages; }
+inline u_int SendFaxJob::getNoCountCover() const	{ return nocountcover; }
+inline bool SendFaxJob::getServerDoCover() const	{ return serverdocover; }
+inline bool SendFaxJob::getIgnoreModemBusy() const	{ return ignoremodembusy; }
 #endif /* _SendFaxJob_ */
